/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CompNamingEvent.java 4310 2008-11-13 09:50:55Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.event.naming;

import org.ow2.easybeans.api.Factory;
import org.ow2.easybeans.event.AbstractEvent;

import javax.naming.Context;
import java.util.List;
import java.util.LinkedList;

/**
 * A CompNamingEvent is an IEvent fired/dispatched during bean's context building phase.
 * @author Guillaume Sauthier
 */
public class CompNamingEvent extends AbstractEvent {

    /**
     * The EJB factory for which the context will be filled.
     */
    private Factory<?, ?> factory;

    /**
     * The target context (can be <code>java:comp</code> or <code>java:comp/env</code>).
     */
    private Context context;

    /**
     * The list of Throwables that may be thrown by the listeners.
     */
    private List<Throwable> throwables;

    /**
     * The default constructor.
     *
     * @param source The event source.
     * @param context the target Context
     * @param factory the EJB factory
     */
    public CompNamingEvent(final String source,
                           final Context context,
                           final Factory<?, ?> factory) {
        super(source);
        this.throwables = new LinkedList<Throwable>();
        this.factory = factory;
        this.context = context;
    }

    /**
     * @return the EasyBeans EJB factory.
     */
    public Factory<?, ?> getFactory() {
        return factory;
    }

    /**
     * @return the processed Context.
     */
    public Context getContext() {
        return context;
    }

    /**
     * @return the list of throwables thrown by listeners.
     */
    public List<Throwable> getThrowables() {
        return throwables;
    }

    /**
     * Append a new Throwable in the list of throwables thrown by listeners.
     * @param throwable Added exception
     */
    public void addThrowable(final Throwable throwable) {
        this.throwables.add(throwable);
    }
}
