/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StatefulCalcBean.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.mavenplugin.examples.calculator;

import javax.ejb.Remote;
import javax.ejb.Stateful;

/**
 * Stateful bean of the calculator.
 * @author Julien Blais
 */
@Stateful
@Remote(StatefulCalcRemote.class)
public class StatefulCalcBean implements StatefulCalcRemote {

    /**
     * Actual state of the bean.
     */
    private int calcValue = 0;

    /**
     * Initialize the calc value.
     */
    public StatefulCalcBean() {
        calcValue = 0;
    }

    /**
     * Set the initial value of the calculator.
     * @param initValue the initial value of the calculator
     */
    public void initial(final int initValue) {
        calcValue = initValue;
    }


    /**
     * Add to the current value.
     * @param toAdd the value to add
     */
    public void add(final int toAdd) {
        calcValue = calcValue + toAdd;
    }


    /**
     * Delete from the current value.
     * @param toDel the value to delete
     */
    public void del(final int toDel) {
        calcValue = calcValue - toDel;
    }

    
    /**
     * Divide the current value.
     * @param toDiv the value used to divide
     */
    public void div(final int toDiv) {
        if (toDiv == 0) {
            throw new IllegalArgumentException("cannot divide by 0");
        }
        calcValue = calcValue / toDiv;
    }

    /**
     * Multiply the current value.
     * @param toMul the value used to multipy
     */
    public void mul(final int toMul) {
        calcValue = calcValue * toMul;
    }

    /**
     * Return the value of the calculator.
     * @return the current value of the calculator
     */
    public int result() {
        return calcValue;
    }
}
